@@ -16,6 +16,7 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 # Import from the standard library
+import re
 from sys import version_info, stdout
 from time import sleep
 
@@ -34,6 +35,8 @@ else:
 
 def isnew(entry):
     if config.key not in entry:
+        if config.ignore_key_error:
+            return False
         raise FeedKeyError(config.key)
 
     for item in tail:
@@ -45,6 +48,8 @@ def isnew(entry):
 def show(entry):
     try:
         output = format(entry)
+        if config.no_endl:
+            output = re.sub(r"[\t\r\n\s]+", r" ", output)
     except KeyError, key:
         raise FeedKeyError(key.args[0])
     else:
@@ -56,13 +61,19 @@ def show(entry):
 def loop():
     def cycle(number=None):
         global tail
-        entries = parse(config.url).entries
-
-        if number is not None and number < len(entries):
-            entries = entries[:number]
+        try:
+            entries = parse(config.url).entries
+        except MemoryError:
+            return
 
         if config.reverse:
             entries.reverse()
+
+        if number is not None and number <= len(entries):
+            for entry in entries[number:]:
+                tail = [entry] + tail[:100]
+            entries = entries[:number]
+
         for entry in entries:
             if isnew(entry):
                 tail = [entry] + tail[:100]
